Information Retrieval API
=========================



Collection
----------

.. autoxpmconfig:: datamaestro_text.data.ir.Adhoc

Topics
------

.. autoxpmconfig:: datamaestro_text.data.ir.AdhocTopics
    :members: iter


.. autoclass:: datamaestro_text.data.ir.AdhocTopic

Documents
---------

.. autoxpmconfig:: datamaestro_text.data.ir.AdhocDocuments
.. autoxpmconfig:: datamaestro_text.data.ir.cord19.Documents


Assessments
-----------

.. autoxpmconfig:: datamaestro_text.data.ir.AdhocAssessments
    :members:


Training triplets
-----------------


.. autoxpmconfig:: datamaestro_text.data.ir.TrainingTriplets
    :members:

.. autoxpmconfig:: datamaestro_text.data.ir.TrainingTripletsLines
.. autoxpmconfig:: datamaestro_text.data.ir.csv.TrainingTripletsID
